@@ -52,7 +52,7 @@ class submit_job(ExperimentalCommandMixIn, Command):
         try:
             job_id = server.scheduler.submit_job(command_text)
         except xmlrpclib.Fault, e:
-            raise LavaCommandError(str(e))
+            raise CommandError(str(e))
         else:
             print "submitted as job id:", job_id
 
